@@ -23,6 +23,11 @@
         <source>Delete</source>
         <translation type="unfinished">Eliminar</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="10"/>
+        <source>Edit</source>
+        <translation type="unfinished">Editar</translation>
+    </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Share</source>
@@ -353,6 +358,11 @@
         <source>Icons Style</source>
         <translation type="unfinished">Estilo de íconos</translation>
     </message>
+    <message>
+        <location filename="../settings.cpp" line="10"/>
+        <source>Text Editor</source>
+        <translation type="unfinished">Editor de texto</translation>
+    </message>
     <message>
         <location filename="../settings.cpp" line="10"/>
         <source>Enable root access (restart needed)</source>
